# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from azure.core.exceptions import HttpResponseError
import msrest.serialization


class Resource(msrest.serialization.Model):
    """Common fields that are returned in the response for all Azure Resource Manager resources.

    Variables are only populated by the server, and will be ignored when sending a request.

    :ivar id: Fully qualified resource ID for the resource. Ex -
     /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}.
    :vartype id: str
    :ivar name: The name of the resource.
    :vartype name: str
    :ivar type: The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or
     "Microsoft.Storage/storageAccounts".
    :vartype type: str
    """

    _validation = {
        'id': {'readonly': True},
        'name': {'readonly': True},
        'type': {'readonly': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(Resource, self).__init__(**kwargs)
        self.id = None
        self.name = None
        self.type = None


class ProxyResource(Resource):
    """The resource model definition for a Azure Resource Manager proxy resource. It will not have tags and a location.

    Variables are only populated by the server, and will be ignored when sending a request.

    :ivar id: Fully qualified resource ID for the resource. Ex -
     /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}.
    :vartype id: str
    :ivar name: The name of the resource.
    :vartype name: str
    :ivar type: The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or
     "Microsoft.Storage/storageAccounts".
    :vartype type: str
    """

    _validation = {
        'id': {'readonly': True},
        'name': {'readonly': True},
        'type': {'readonly': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(ProxyResource, self).__init__(**kwargs)


class ClusterScopeSettings(ProxyResource):
    """Extension scope settings.

    Variables are only populated by the server, and will be ignored when sending a request.

    :ivar id: Fully qualified resource ID for the resource. Ex -
     /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}.
    :vartype id: str
    :ivar name: The name of the resource.
    :vartype name: str
    :ivar type: The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or
     "Microsoft.Storage/storageAccounts".
    :vartype type: str
    :param allow_multiple_instances: Describes if multiple instances of the extension are allowed.
    :type allow_multiple_instances: bool
    :param default_release_namespace: Default extension release namespace.
    :type default_release_namespace: str
    """

    _validation = {
        'id': {'readonly': True},
        'name': {'readonly': True},
        'type': {'readonly': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'allow_multiple_instances': {'key': 'properties.allowMultipleInstances', 'type': 'bool'},
        'default_release_namespace': {'key': 'properties.defaultReleaseNamespace', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(ClusterScopeSettings, self).__init__(**kwargs)
        self.allow_multiple_instances = kwargs.get('allow_multiple_instances', None)
        self.default_release_namespace = kwargs.get('default_release_namespace', None)


class ComplianceStatus(msrest.serialization.Model):
    """Compliance Status details.

    Variables are only populated by the server, and will be ignored when sending a request.

    :ivar compliance_state: The compliance state of the configuration. Possible values include:
     "Pending", "Compliant", "Noncompliant", "Installed", "Failed".
    :vartype compliance_state: str or
     ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.ComplianceStateType
    :param last_config_applied: Datetime the configuration was last applied.
    :type last_config_applied: ~datetime.datetime
    :param message: Message from when the configuration was applied.
    :type message: str
    :param message_level: Level of the message. Possible values include: "Error", "Warning",
     "Information".
    :type message_level: str or
     ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.MessageLevelType
    """

    _validation = {
        'compliance_state': {'readonly': True},
    }

    _attribute_map = {
        'compliance_state': {'key': 'complianceState', 'type': 'str'},
        'last_config_applied': {'key': 'lastConfigApplied', 'type': 'iso-8601'},
        'message': {'key': 'message', 'type': 'str'},
        'message_level': {'key': 'messageLevel', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(ComplianceStatus, self).__init__(**kwargs)
        self.compliance_state = None
        self.last_config_applied = kwargs.get('last_config_applied', None)
        self.message = kwargs.get('message', None)
        self.message_level = kwargs.get('message_level', None)


class DependsOnDefinition(msrest.serialization.Model):
    """Specify which kustomizations must succeed reconciliation on the cluster prior to reconciling this kustomization.

    :param kustomization_name: Name of the kustomization to claim dependency on.
    :type kustomization_name: str
    """

    _attribute_map = {
        'kustomization_name': {'key': 'kustomizationName', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(DependsOnDefinition, self).__init__(**kwargs)
        self.kustomization_name = kwargs.get('kustomization_name', None)


class ErrorAdditionalInfo(msrest.serialization.Model):
    """The resource management error additional info.

    Variables are only populated by the server, and will be ignored when sending a request.

    :ivar type: The additional info type.
    :vartype type: str
    :ivar info: The additional info.
    :vartype info: any
    """

    _validation = {
        'type': {'readonly': True},
        'info': {'readonly': True},
    }

    _attribute_map = {
        'type': {'key': 'type', 'type': 'str'},
        'info': {'key': 'info', 'type': 'object'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(ErrorAdditionalInfo, self).__init__(**kwargs)
        self.type = None
        self.info = None


class ErrorDetail(msrest.serialization.Model):
    """The error detail.

    Variables are only populated by the server, and will be ignored when sending a request.

    :ivar code: The error code.
    :vartype code: str
    :ivar message: The error message.
    :vartype message: str
    :ivar target: The error target.
    :vartype target: str
    :ivar details: The error details.
    :vartype details:
     list[~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.ErrorDetail]
    :ivar additional_info: The error additional info.
    :vartype additional_info:
     list[~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.ErrorAdditionalInfo]
    """

    _validation = {
        'code': {'readonly': True},
        'message': {'readonly': True},
        'target': {'readonly': True},
        'details': {'readonly': True},
        'additional_info': {'readonly': True},
    }

    _attribute_map = {
        'code': {'key': 'code', 'type': 'str'},
        'message': {'key': 'message', 'type': 'str'},
        'target': {'key': 'target', 'type': 'str'},
        'details': {'key': 'details', 'type': '[ErrorDetail]'},
        'additional_info': {'key': 'additionalInfo', 'type': '[ErrorAdditionalInfo]'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(ErrorDetail, self).__init__(**kwargs)
        self.code = None
        self.message = None
        self.target = None
        self.details = None
        self.additional_info = None


class ErrorResponse(msrest.serialization.Model):
    """Common error response for all Azure Resource Manager APIs to return error details for failed operations. (This also follows the OData error response format.).

    :param error: The error object.
    :type error: ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.ErrorDetail
    """

    _attribute_map = {
        'error': {'key': 'error', 'type': 'ErrorDetail'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(ErrorResponse, self).__init__(**kwargs)
        self.error = kwargs.get('error', None)


class Extension(ProxyResource):
    """The Extension object.

    Variables are only populated by the server, and will be ignored when sending a request.

    :ivar id: Fully qualified resource ID for the resource. Ex -
     /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}.
    :vartype id: str
    :ivar name: The name of the resource.
    :vartype name: str
    :ivar type: The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or
     "Microsoft.Storage/storageAccounts".
    :vartype type: str
    :param identity: Identity of the Extension resource.
    :type identity: ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.Identity
    :ivar system_data: Top level metadata
     https://github.com/Azure/azure-resource-manager-rpc/blob/master/v1.0/common-api-contracts.md#system-metadata-for-all-azure-resources.
    :vartype system_data: ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.SystemData
    :param extension_type: Type of the Extension, of which this resource is an instance of.  It
     must be one of the Extension Types registered with Microsoft.KubernetesConfiguration by the
     Extension publisher.
    :type extension_type: str
    :param auto_upgrade_minor_version: Flag to note if this extension participates in auto upgrade
     of minor version, or not.
    :type auto_upgrade_minor_version: bool
    :param release_train: ReleaseTrain this extension participates in for auto-upgrade (e.g.
     Stable, Preview, etc.) - only if autoUpgradeMinorVersion is 'true'.
    :type release_train: str
    :param version: Version of the extension for this extension, if it is 'pinned' to a specific
     version. autoUpgradeMinorVersion must be 'false'.
    :type version: str
    :param scope: Scope at which the extension is installed.
    :type scope: ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.Scope
    :param configuration_settings: Configuration settings, as name-value pairs for configuring this
     extension.
    :type configuration_settings: dict[str, str]
    :param configuration_protected_settings: Configuration settings that are sensitive, as
     name-value pairs for configuring this extension.
    :type configuration_protected_settings: dict[str, str]
    :ivar provisioning_state: Status of installation of this extension. Possible values include:
     "Succeeded", "Failed", "Canceled", "Creating", "Updating", "Deleting".
    :vartype provisioning_state: str or
     ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.ProvisioningState
    :param statuses: Status from this extension.
    :type statuses:
     list[~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.ExtensionStatus]
    :ivar error_info: Error information from the Agent - e.g. errors during installation.
    :vartype error_info: ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.ErrorDetail
    :ivar custom_location_settings: Custom Location settings properties.
    :vartype custom_location_settings: dict[str, str]
    :ivar package_uri: Uri of the Helm package.
    :vartype package_uri: str
    :param aks_assigned_identity: Identity of the Extension resource in an AKS cluster.
    :type aks_assigned_identity:
     ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.ExtensionPropertiesAksAssignedIdentity
    """

    _validation = {
        'id': {'readonly': True},
        'name': {'readonly': True},
        'type': {'readonly': True},
        'system_data': {'readonly': True},
        'provisioning_state': {'readonly': True},
        'error_info': {'readonly': True},
        'custom_location_settings': {'readonly': True},
        'package_uri': {'readonly': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'identity': {'key': 'identity', 'type': 'Identity'},
        'system_data': {'key': 'systemData', 'type': 'SystemData'},
        'extension_type': {'key': 'properties.extensionType', 'type': 'str'},
        'auto_upgrade_minor_version': {'key': 'properties.autoUpgradeMinorVersion', 'type': 'bool'},
        'release_train': {'key': 'properties.releaseTrain', 'type': 'str'},
        'version': {'key': 'properties.version', 'type': 'str'},
        'scope': {'key': 'properties.scope', 'type': 'Scope'},
        'configuration_settings': {'key': 'properties.configurationSettings', 'type': '{str}'},
        'configuration_protected_settings': {'key': 'properties.configurationProtectedSettings', 'type': '{str}'},
        'provisioning_state': {'key': 'properties.provisioningState', 'type': 'str'},
        'statuses': {'key': 'properties.statuses', 'type': '[ExtensionStatus]'},
        'error_info': {'key': 'properties.errorInfo', 'type': 'ErrorDetail'},
        'custom_location_settings': {'key': 'properties.customLocationSettings', 'type': '{str}'},
        'package_uri': {'key': 'properties.packageUri', 'type': 'str'},
        'aks_assigned_identity': {'key': 'properties.aksAssignedIdentity', 'type': 'ExtensionPropertiesAksAssignedIdentity'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(Extension, self).__init__(**kwargs)
        self.identity = kwargs.get('identity', None)
        self.system_data = None
        self.extension_type = kwargs.get('extension_type', None)
        self.auto_upgrade_minor_version = kwargs.get('auto_upgrade_minor_version', True)
        self.release_train = kwargs.get('release_train', "Stable")
        self.version = kwargs.get('version', None)
        self.scope = kwargs.get('scope', None)
        self.configuration_settings = kwargs.get('configuration_settings', None)
        self.configuration_protected_settings = kwargs.get('configuration_protected_settings', None)
        self.provisioning_state = None
        self.statuses = kwargs.get('statuses', None)
        self.error_info = None
        self.custom_location_settings = None
        self.package_uri = None
        self.aks_assigned_identity = kwargs.get('aks_assigned_identity', None)


class ExtensionPropertiesAksAssignedIdentity(msrest.serialization.Model):
    """Identity of the Extension resource in an AKS cluster.

    Variables are only populated by the server, and will be ignored when sending a request.

    :ivar principal_id: The principal ID of resource identity.
    :vartype principal_id: str
    :ivar tenant_id: The tenant ID of resource.
    :vartype tenant_id: str
    :param type: The identity type. The only acceptable values to pass in are None and
     "SystemAssigned". The default value is None.
    :type type: str
    """

    _validation = {
        'principal_id': {'readonly': True},
        'tenant_id': {'readonly': True},
    }

    _attribute_map = {
        'principal_id': {'key': 'principalId', 'type': 'str'},
        'tenant_id': {'key': 'tenantId', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(ExtensionPropertiesAksAssignedIdentity, self).__init__(**kwargs)
        self.principal_id = None
        self.tenant_id = None
        self.type = kwargs.get('type', None)


class ExtensionsList(msrest.serialization.Model):
    """Result of the request to list Extensions.  It contains a list of Extension objects and a URL link to get the next set of results.

    Variables are only populated by the server, and will be ignored when sending a request.

    :ivar value: List of Extensions within a Kubernetes cluster.
    :vartype value: list[~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.Extension]
    :ivar next_link: URL to get the next set of extension objects, if any.
    :vartype next_link: str
    """

    _validation = {
        'value': {'readonly': True},
        'next_link': {'readonly': True},
    }

    _attribute_map = {
        'value': {'key': 'value', 'type': '[Extension]'},
        'next_link': {'key': 'nextLink', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(ExtensionsList, self).__init__(**kwargs)
        self.value = None
        self.next_link = None


class ExtensionStatus(msrest.serialization.Model):
    """Status from the extension.

    :param code: Status code provided by the Extension.
    :type code: str
    :param display_status: Short description of status of the extension.
    :type display_status: str
    :param level: Level of the status. Possible values include: "Error", "Warning", "Information".
     Default value: "Information".
    :type level: str or ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.LevelType
    :param message: Detailed message of the status from the Extension.
    :type message: str
    :param time: DateLiteral (per ISO8601) noting the time of installation status.
    :type time: str
    """

    _attribute_map = {
        'code': {'key': 'code', 'type': 'str'},
        'display_status': {'key': 'displayStatus', 'type': 'str'},
        'level': {'key': 'level', 'type': 'str'},
        'message': {'key': 'message', 'type': 'str'},
        'time': {'key': 'time', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(ExtensionStatus, self).__init__(**kwargs)
        self.code = kwargs.get('code', None)
        self.display_status = kwargs.get('display_status', None)
        self.level = kwargs.get('level', "Information")
        self.message = kwargs.get('message', None)
        self.time = kwargs.get('time', None)


class ExtensionType(msrest.serialization.Model):
    """Represents an Extension Type.

    Variables are only populated by the server, and will be ignored when sending a request.

    :ivar system_data: Metadata pertaining to creation and last modification of the resource.
    :vartype system_data: ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.SystemData
    :ivar release_trains: Extension release train: preview or stable.
    :vartype release_trains: list[str]
    :ivar cluster_types: Cluster types. Possible values include: "connectedClusters",
     "managedClusters".
    :vartype cluster_types: str or
     ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.ClusterTypes
    :ivar supported_scopes: Extension scopes.
    :vartype supported_scopes:
     ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.SupportedScopes
    """

    _validation = {
        'system_data': {'readonly': True},
        'release_trains': {'readonly': True},
        'cluster_types': {'readonly': True},
        'supported_scopes': {'readonly': True},
    }

    _attribute_map = {
        'system_data': {'key': 'systemData', 'type': 'SystemData'},
        'release_trains': {'key': 'properties.releaseTrains', 'type': '[str]'},
        'cluster_types': {'key': 'properties.clusterTypes', 'type': 'str'},
        'supported_scopes': {'key': 'properties.supportedScopes', 'type': 'SupportedScopes'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(ExtensionType, self).__init__(**kwargs)
        self.system_data = None
        self.release_trains = None
        self.cluster_types = None
        self.supported_scopes = None


class ExtensionTypeList(msrest.serialization.Model):
    """List Extension Types.

    :param value: The list of Extension Types.
    :type value: list[~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.ExtensionType]
    :param next_link: The link to fetch the next page of Extension Types.
    :type next_link: str
    """

    _attribute_map = {
        'value': {'key': 'value', 'type': '[ExtensionType]'},
        'next_link': {'key': 'nextLink', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(ExtensionTypeList, self).__init__(**kwargs)
        self.value = kwargs.get('value', None)
        self.next_link = kwargs.get('next_link', None)


class ExtensionVersionList(msrest.serialization.Model):
    """List versions for an Extension.

    Variables are only populated by the server, and will be ignored when sending a request.

    :param versions: Versions available for this Extension Type.
    :type versions:
     list[~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.ExtensionVersionListVersionsItem]
    :param next_link: The link to fetch the next page of Extension Types.
    :type next_link: str
    :ivar system_data: Metadata pertaining to creation and last modification of the resource.
    :vartype system_data: ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.SystemData
    """

    _validation = {
        'system_data': {'readonly': True},
    }

    _attribute_map = {
        'versions': {'key': 'versions', 'type': '[ExtensionVersionListVersionsItem]'},
        'next_link': {'key': 'nextLink', 'type': 'str'},
        'system_data': {'key': 'systemData', 'type': 'SystemData'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(ExtensionVersionList, self).__init__(**kwargs)
        self.versions = kwargs.get('versions', None)
        self.next_link = kwargs.get('next_link', None)
        self.system_data = None


class ExtensionVersionListVersionsItem(msrest.serialization.Model):
    """ExtensionVersionListVersionsItem.

    :param release_train: The release train for this Extension Type.
    :type release_train: str
    :param versions: Versions available for this Extension Type and release train.
    :type versions: list[str]
    """

    _attribute_map = {
        'release_train': {'key': 'releaseTrain', 'type': 'str'},
        'versions': {'key': 'versions', 'type': '[str]'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(ExtensionVersionListVersionsItem, self).__init__(**kwargs)
        self.release_train = kwargs.get('release_train', None)
        self.versions = kwargs.get('versions', None)


class FluxConfiguration(ProxyResource):
    """The Flux Configuration object returned in Get & Put response.

    Variables are only populated by the server, and will be ignored when sending a request.

    :ivar id: Fully qualified resource ID for the resource. Ex -
     /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}.
    :vartype id: str
    :ivar name: The name of the resource.
    :vartype name: str
    :ivar type: The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or
     "Microsoft.Storage/storageAccounts".
    :vartype type: str
    :ivar system_data: Top level metadata
     https://github.com/Azure/azure-resource-manager-rpc/blob/master/v1.0/common-api-contracts.md#system-metadata-for-all-azure-resources.
    :vartype system_data: ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.SystemData
    :param scope: Scope at which the operator will be installed. Possible values include:
     "cluster", "namespace". Default value: "cluster".
    :type scope: str or ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.ScopeType
    :param namespace: The namespace to which this configuration is installed to. Maximum of 253
     lower case alphanumeric characters, hyphen and period only.
    :type namespace: str
    :param source_kind: Source Kind to pull the configuration data from. Possible values include:
     "GitRepository".
    :type source_kind: str or
     ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.SourceKindType
    :param suspend: Whether this configuration should suspend its reconciliation of its
     kustomizations and sources.
    :type suspend: bool
    :param git_repository: Parameters to reconcile to the GitRepository source kind type.
    :type git_repository:
     ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.GitRepositoryDefinition
    :param kustomizations: Array of kustomizations used to reconcile the artifact pulled by the
     source type on the cluster.
    :type kustomizations: dict[str,
     ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.KustomizationDefinition]
    :param configuration_protected_settings: Key-value pairs of protected configuration settings
     for the configuration.
    :type configuration_protected_settings: dict[str, str]
    :ivar statuses: Statuses of the Flux Kubernetes resources created by the fluxConfiguration or
     created by the managed objects provisioned by the fluxConfiguration.
    :vartype statuses:
     list[~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.ObjectStatusDefinition]
    :ivar repository_public_key: Public Key associated with this fluxConfiguration (either
     generated within the cluster or provided by the user).
    :vartype repository_public_key: str
    :ivar last_source_synced_commit_id: Branch and SHA of the last source commit synced with the
     cluster.
    :vartype last_source_synced_commit_id: str
    :ivar last_source_synced_at: Datetime the fluxConfiguration last synced its source on the
     cluster.
    :vartype last_source_synced_at: ~datetime.datetime
    :ivar compliance_state: Combined status of the Flux Kubernetes resources created by the
     fluxConfiguration or created by the managed objects. Possible values include: "Compliant",
     "Non-Compliant", "Pending", "Suspended", "Unknown". Default value: "Unknown".
    :vartype compliance_state: str or
     ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.FluxComplianceState
    :ivar provisioning_state: Status of the creation of the fluxConfiguration. Possible values
     include: "Succeeded", "Failed", "Canceled", "Creating", "Updating", "Deleting".
    :vartype provisioning_state: str or
     ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.ProvisioningState
    :ivar error_message: Error message returned to the user in the case of provisioning failure.
    :vartype error_message: str
    """

    _validation = {
        'id': {'readonly': True},
        'name': {'readonly': True},
        'type': {'readonly': True},
        'system_data': {'readonly': True},
        'statuses': {'readonly': True},
        'repository_public_key': {'readonly': True},
        'last_source_synced_commit_id': {'readonly': True},
        'last_source_synced_at': {'readonly': True},
        'compliance_state': {'readonly': True},
        'provisioning_state': {'readonly': True},
        'error_message': {'readonly': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'system_data': {'key': 'systemData', 'type': 'SystemData'},
        'scope': {'key': 'properties.scope', 'type': 'str'},
        'namespace': {'key': 'properties.namespace', 'type': 'str'},
        'source_kind': {'key': 'properties.sourceKind', 'type': 'str'},
        'suspend': {'key': 'properties.suspend', 'type': 'bool'},
        'git_repository': {'key': 'properties.gitRepository', 'type': 'GitRepositoryDefinition'},
        'kustomizations': {'key': 'properties.kustomizations', 'type': '{KustomizationDefinition}'},
        'configuration_protected_settings': {'key': 'properties.configurationProtectedSettings', 'type': '{str}'},
        'statuses': {'key': 'properties.statuses', 'type': '[ObjectStatusDefinition]'},
        'repository_public_key': {'key': 'properties.repositoryPublicKey', 'type': 'str'},
        'last_source_synced_commit_id': {'key': 'properties.lastSourceSyncedCommitId', 'type': 'str'},
        'last_source_synced_at': {'key': 'properties.lastSourceSyncedAt', 'type': 'iso-8601'},
        'compliance_state': {'key': 'properties.complianceState', 'type': 'str'},
        'provisioning_state': {'key': 'properties.provisioningState', 'type': 'str'},
        'error_message': {'key': 'properties.errorMessage', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(FluxConfiguration, self).__init__(**kwargs)
        self.system_data = None
        self.scope = kwargs.get('scope', "cluster")
        self.namespace = kwargs.get('namespace', "default")
        self.source_kind = kwargs.get('source_kind', None)
        self.suspend = kwargs.get('suspend', False)
        self.git_repository = kwargs.get('git_repository', None)
        self.kustomizations = kwargs.get('kustomizations', None)
        self.configuration_protected_settings = kwargs.get('configuration_protected_settings', None)
        self.statuses = None
        self.repository_public_key = None
        self.last_source_synced_commit_id = None
        self.last_source_synced_at = None
        self.compliance_state = None
        self.provisioning_state = None
        self.error_message = None


class FluxConfigurationPatch(msrest.serialization.Model):
    """The Flux Configuration Patch Request object.

    :param source_kind: Source Kind to pull the configuration data from. Possible values include:
     "GitRepository".
    :type source_kind: str or
     ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.SourceKindType
    :param suspend: Whether this configuration should suspend its reconciliation of its
     kustomizations and sources.
    :type suspend: bool
    :param git_repository: Parameters to reconcile to the GitRepository source kind type.
    :type git_repository:
     ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.GitRepositoryDefinition
    :param kustomizations: Array of kustomizations used to reconcile the artifact pulled by the
     source type on the cluster.
    :type kustomizations: dict[str,
     ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.KustomizationDefinition]
    :param configuration_protected_settings: Key-value pairs of protected configuration settings
     for the configuration.
    :type configuration_protected_settings: dict[str, str]
    """

    _attribute_map = {
        'source_kind': {'key': 'properties.sourceKind', 'type': 'str'},
        'suspend': {'key': 'properties.suspend', 'type': 'bool'},
        'git_repository': {'key': 'properties.gitRepository', 'type': 'GitRepositoryDefinition'},
        'kustomizations': {'key': 'properties.kustomizations', 'type': '{KustomizationDefinition}'},
        'configuration_protected_settings': {'key': 'properties.configurationProtectedSettings', 'type': '{str}'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(FluxConfigurationPatch, self).__init__(**kwargs)
        self.source_kind = kwargs.get('source_kind', None)
        self.suspend = kwargs.get('suspend', False)
        self.git_repository = kwargs.get('git_repository', None)
        self.kustomizations = kwargs.get('kustomizations', None)
        self.configuration_protected_settings = kwargs.get('configuration_protected_settings', None)


class FluxConfigurationsList(msrest.serialization.Model):
    """Result of the request to list Flux Configurations.  It contains a list of FluxConfiguration objects and a URL link to get the next set of results.

    Variables are only populated by the server, and will be ignored when sending a request.

    :ivar value: List of Flux Configurations within a Kubernetes cluster.
    :vartype value:
     list[~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.FluxConfiguration]
    :ivar next_link: URL to get the next set of configuration objects, if any.
    :vartype next_link: str
    """

    _validation = {
        'value': {'readonly': True},
        'next_link': {'readonly': True},
    }

    _attribute_map = {
        'value': {'key': 'value', 'type': '[FluxConfiguration]'},
        'next_link': {'key': 'nextLink', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(FluxConfigurationsList, self).__init__(**kwargs)
        self.value = None
        self.next_link = None


class GitRepositoryDefinition(msrest.serialization.Model):
    """Parameters to reconcile to the GitRepository source kind type.

    :param url: The URL to sync for the flux configuration git repository.
    :type url: str
    :param timeout_in_seconds: The maximum time to attempt to reconcile the cluster git repository
     source with the remote.
    :type timeout_in_seconds: long
    :param sync_interval_in_seconds: The interval at which to re-reconcile the cluster git
     repository source with the remote.
    :type sync_interval_in_seconds: long
    :param repository_ref: The source reference for the GitRepository object.
    :type repository_ref:
     ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.RepositoryRefDefinition
    :param ssh_known_hosts: Base64-encoded known_hosts value containing public SSH keys required to
     access private git repositories over SSH.
    :type ssh_known_hosts: str
    :param https_user: Base64-encoded HTTPS username used to access private git repositories over
     HTTPS.
    :type https_user: str
    :param https_ca_file: Base64-encoded HTTPS certificate authority contents used to access git
     private git repositories over HTTPS.
    :type https_ca_file: str
    :param local_auth_ref: Name of a local secret on the Kubernetes cluster to use as the
     authentication secret rather than the managed or user-provided configuration secrets.
    :type local_auth_ref: str
    """

    _attribute_map = {
        'url': {'key': 'url', 'type': 'str'},
        'timeout_in_seconds': {'key': 'timeoutInSeconds', 'type': 'long'},
        'sync_interval_in_seconds': {'key': 'syncIntervalInSeconds', 'type': 'long'},
        'repository_ref': {'key': 'repositoryRef', 'type': 'RepositoryRefDefinition'},
        'ssh_known_hosts': {'key': 'sshKnownHosts', 'type': 'str'},
        'https_user': {'key': 'httpsUser', 'type': 'str'},
        'https_ca_file': {'key': 'httpsCAFile', 'type': 'str'},
        'local_auth_ref': {'key': 'localAuthRef', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(GitRepositoryDefinition, self).__init__(**kwargs)
        self.url = kwargs.get('url', None)
        self.timeout_in_seconds = kwargs.get('timeout_in_seconds', 600)
        self.sync_interval_in_seconds = kwargs.get('sync_interval_in_seconds', 600)
        self.repository_ref = kwargs.get('repository_ref', None)
        self.ssh_known_hosts = kwargs.get('ssh_known_hosts', None)
        self.https_user = kwargs.get('https_user', None)
        self.https_ca_file = kwargs.get('https_ca_file', None)
        self.local_auth_ref = kwargs.get('local_auth_ref', None)


class HelmOperatorProperties(msrest.serialization.Model):
    """Properties for Helm operator.

    :param chart_version: Version of the operator Helm chart.
    :type chart_version: str
    :param chart_values: Values override for the operator Helm chart.
    :type chart_values: str
    """

    _attribute_map = {
        'chart_version': {'key': 'chartVersion', 'type': 'str'},
        'chart_values': {'key': 'chartValues', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(HelmOperatorProperties, self).__init__(**kwargs)
        self.chart_version = kwargs.get('chart_version', None)
        self.chart_values = kwargs.get('chart_values', None)


class HelmReleasePropertiesDefinition(msrest.serialization.Model):
    """HelmReleasePropertiesDefinition.

    :param last_revision_applied: The revision number of the last released object change.
    :type last_revision_applied: long
    :param helm_chart_ref: The reference to the HelmChart object used as the source to this
     HelmRelease.
    :type helm_chart_ref:
     ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.ObjectReferenceDefinition
    :param failure_count: Total number of times that the HelmRelease failed to install or upgrade.
    :type failure_count: long
    :param install_failure_count: Number of times that the HelmRelease failed to install.
    :type install_failure_count: long
    :param upgrade_failure_count: Number of times that the HelmRelease failed to upgrade.
    :type upgrade_failure_count: long
    """

    _attribute_map = {
        'last_revision_applied': {'key': 'lastRevisionApplied', 'type': 'long'},
        'helm_chart_ref': {'key': 'helmChartRef', 'type': 'ObjectReferenceDefinition'},
        'failure_count': {'key': 'failureCount', 'type': 'long'},
        'install_failure_count': {'key': 'installFailureCount', 'type': 'long'},
        'upgrade_failure_count': {'key': 'upgradeFailureCount', 'type': 'long'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(HelmReleasePropertiesDefinition, self).__init__(**kwargs)
        self.last_revision_applied = kwargs.get('last_revision_applied', None)
        self.helm_chart_ref = kwargs.get('helm_chart_ref', None)
        self.failure_count = kwargs.get('failure_count', None)
        self.install_failure_count = kwargs.get('install_failure_count', None)
        self.upgrade_failure_count = kwargs.get('upgrade_failure_count', None)


class Identity(msrest.serialization.Model):
    """Identity for the resource.

    Variables are only populated by the server, and will be ignored when sending a request.

    :ivar principal_id: The principal ID of resource identity.
    :vartype principal_id: str
    :ivar tenant_id: The tenant ID of resource.
    :vartype tenant_id: str
    :param type: The identity type. The only acceptable values to pass in are None and
     "SystemAssigned". The default value is None.
    :type type: str
    """

    _validation = {
        'principal_id': {'readonly': True},
        'tenant_id': {'readonly': True},
    }

    _attribute_map = {
        'principal_id': {'key': 'principalId', 'type': 'str'},
        'tenant_id': {'key': 'tenantId', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(Identity, self).__init__(**kwargs)
        self.principal_id = None
        self.tenant_id = None
        self.type = kwargs.get('type', None)


class KustomizationDefinition(msrest.serialization.Model):
    """The Kustomization defining how to reconcile the artifact pulled by the source type on the cluster.

    :param path: The path in the source reference to reconcile on the cluster.
    :type path: str
    :param depends_on: Specifies other Kustomizations that this Kustomization depends on. This
     Kustomization will not reconcile until all dependencies have completed their reconciliation.
    :type depends_on:
     list[~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.DependsOnDefinition]
    :param timeout_in_seconds: The maximum time to attempt to reconcile the Kustomization on the
     cluster.
    :type timeout_in_seconds: long
    :param sync_interval_in_seconds: The interval at which to re-reconcile the Kustomization on the
     cluster.
    :type sync_interval_in_seconds: long
    :param retry_interval_in_seconds: The interval at which to re-reconcile the Kustomization on
     the cluster in the event of failure on reconciliation.
    :type retry_interval_in_seconds: long
    :param prune: Enable/disable garbage collections of Kubernetes objects created by this
     Kustomization.
    :type prune: bool
    :param validation: Specify whether to validate the Kubernetes objects referenced in the
     Kustomization before applying them to the cluster. Possible values include: "none", "client",
     "server". Default value: "none".
    :type validation: str or
     ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.KustomizationValidationType
    :param force: Enable/disable re-creating Kubernetes resources on the cluster when patching
     fails due to an immutable field change.
    :type force: bool
    """

    _attribute_map = {
        'path': {'key': 'path', 'type': 'str'},
        'depends_on': {'key': 'dependsOn', 'type': '[DependsOnDefinition]'},
        'timeout_in_seconds': {'key': 'timeoutInSeconds', 'type': 'long'},
        'sync_interval_in_seconds': {'key': 'syncIntervalInSeconds', 'type': 'long'},
        'retry_interval_in_seconds': {'key': 'retryIntervalInSeconds', 'type': 'long'},
        'prune': {'key': 'prune', 'type': 'bool'},
        'validation': {'key': 'validation', 'type': 'str'},
        'force': {'key': 'force', 'type': 'bool'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(KustomizationDefinition, self).__init__(**kwargs)
        self.path = kwargs.get('path', "")
        self.depends_on = kwargs.get('depends_on', None)
        self.timeout_in_seconds = kwargs.get('timeout_in_seconds', 600)
        self.sync_interval_in_seconds = kwargs.get('sync_interval_in_seconds', 600)
        self.retry_interval_in_seconds = kwargs.get('retry_interval_in_seconds', None)
        self.prune = kwargs.get('prune', False)
        self.validation = kwargs.get('validation', "none")
        self.force = kwargs.get('force', False)


class ObjectReferenceDefinition(msrest.serialization.Model):
    """Object reference to a Kubernetes object on a cluster.

    :param name: Name of the object.
    :type name: str
    :param namespace: Namespace of the object.
    :type namespace: str
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'namespace': {'key': 'namespace', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(ObjectReferenceDefinition, self).__init__(**kwargs)
        self.name = kwargs.get('name', None)
        self.namespace = kwargs.get('namespace', None)


class ObjectStatusConditionDefinition(msrest.serialization.Model):
    """Status condition of Kubernetes object.

    :param last_transition_time: Last time this status condition has changed.
    :type last_transition_time: ~datetime.datetime
    :param message: A more verbose description of the object status condition.
    :type message: str
    :param reason: Reason for the specified status condition type status.
    :type reason: str
    :param status: Status of the Kubernetes object condition type.
    :type status: str
    :param type: Object status condition type for this object.
    :type type: str
    """

    _attribute_map = {
        'last_transition_time': {'key': 'lastTransitionTime', 'type': 'iso-8601'},
        'message': {'key': 'message', 'type': 'str'},
        'reason': {'key': 'reason', 'type': 'str'},
        'status': {'key': 'status', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(ObjectStatusConditionDefinition, self).__init__(**kwargs)
        self.last_transition_time = kwargs.get('last_transition_time', None)
        self.message = kwargs.get('message', None)
        self.reason = kwargs.get('reason', None)
        self.status = kwargs.get('status', None)
        self.type = kwargs.get('type', None)


class ObjectStatusDefinition(msrest.serialization.Model):
    """Statuses of objects deployed by the user-specified kustomizations from the git repository.

    :param name: Name of the applied object.
    :type name: str
    :param namespace: Namespace of the applied object.
    :type namespace: str
    :param kind: Kind of the applied object.
    :type kind: str
    :param compliance_state: Compliance state of the applied object showing whether the applied
     object has come into a ready state on the cluster. Possible values include: "Compliant",
     "Non-Compliant", "Pending", "Suspended", "Unknown". Default value: "Unknown".
    :type compliance_state: str or
     ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.FluxComplianceState
    :param applied_by: Object reference to the Kustomization that applied this object.
    :type applied_by:
     ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.ObjectReferenceDefinition
    :param status_conditions: List of Kubernetes object status conditions present on the cluster.
    :type status_conditions:
     list[~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.ObjectStatusConditionDefinition]
    :param helm_release_properties: Additional properties that are provided from objects of the
     HelmRelease kind.
    :type helm_release_properties:
     ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.HelmReleasePropertiesDefinition
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'namespace': {'key': 'namespace', 'type': 'str'},
        'kind': {'key': 'kind', 'type': 'str'},
        'compliance_state': {'key': 'complianceState', 'type': 'str'},
        'applied_by': {'key': 'appliedBy', 'type': 'ObjectReferenceDefinition'},
        'status_conditions': {'key': 'statusConditions', 'type': '[ObjectStatusConditionDefinition]'},
        'helm_release_properties': {'key': 'helmReleaseProperties', 'type': 'HelmReleasePropertiesDefinition'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(ObjectStatusDefinition, self).__init__(**kwargs)
        self.name = kwargs.get('name', None)
        self.namespace = kwargs.get('namespace', None)
        self.kind = kwargs.get('kind', None)
        self.compliance_state = kwargs.get('compliance_state', "Unknown")
        self.applied_by = kwargs.get('applied_by', None)
        self.status_conditions = kwargs.get('status_conditions', None)
        self.helm_release_properties = kwargs.get('helm_release_properties', None)


class OperationStatusList(msrest.serialization.Model):
    """The async operations in progress, in the cluster.

    Variables are only populated by the server, and will be ignored when sending a request.

    :ivar value: List of async operations in progress, in the cluster.
    :vartype value:
     list[~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.OperationStatusResult]
    :ivar next_link: URL to get the next set of Operation Result objects, if any.
    :vartype next_link: str
    """

    _validation = {
        'value': {'readonly': True},
        'next_link': {'readonly': True},
    }

    _attribute_map = {
        'value': {'key': 'value', 'type': '[OperationStatusResult]'},
        'next_link': {'key': 'nextLink', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(OperationStatusList, self).__init__(**kwargs)
        self.value = None
        self.next_link = None


class OperationStatusResult(msrest.serialization.Model):
    """The current status of an async operation.

    Variables are only populated by the server, and will be ignored when sending a request.

    All required parameters must be populated in order to send to Azure.

    :param id: Fully qualified ID for the async operation.
    :type id: str
    :param name: Name of the async operation.
    :type name: str
    :param status: Required. Operation status.
    :type status: str
    :param properties: Additional information, if available.
    :type properties: dict[str, str]
    :ivar error: If present, details of the operation error.
    :vartype error: ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.ErrorDetail
    """

    _validation = {
        'status': {'required': True},
        'error': {'readonly': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'status': {'key': 'status', 'type': 'str'},
        'properties': {'key': 'properties', 'type': '{str}'},
        'error': {'key': 'error', 'type': 'ErrorDetail'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(OperationStatusResult, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.name = kwargs.get('name', None)
        self.status = kwargs['status']
        self.properties = kwargs.get('properties', None)
        self.error = None


class PatchExtension(msrest.serialization.Model):
    """The Extension Patch Request object.

    :param auto_upgrade_minor_version: Flag to note if this extension participates in auto upgrade
     of minor version, or not.
    :type auto_upgrade_minor_version: bool
    :param release_train: ReleaseTrain this extension participates in for auto-upgrade (e.g.
     Stable, Preview, etc.) - only if autoUpgradeMinorVersion is 'true'.
    :type release_train: str
    :param version: Version of the extension for this extension, if it is 'pinned' to a specific
     version. autoUpgradeMinorVersion must be 'false'.
    :type version: str
    :param configuration_settings: Configuration settings, as name-value pairs for configuring this
     extension.
    :type configuration_settings: dict[str, str]
    :param configuration_protected_settings: Configuration settings that are sensitive, as
     name-value pairs for configuring this extension.
    :type configuration_protected_settings: dict[str, str]
    """

    _attribute_map = {
        'auto_upgrade_minor_version': {'key': 'properties.autoUpgradeMinorVersion', 'type': 'bool'},
        'release_train': {'key': 'properties.releaseTrain', 'type': 'str'},
        'version': {'key': 'properties.version', 'type': 'str'},
        'configuration_settings': {'key': 'properties.configurationSettings', 'type': '{str}'},
        'configuration_protected_settings': {'key': 'properties.configurationProtectedSettings', 'type': '{str}'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(PatchExtension, self).__init__(**kwargs)
        self.auto_upgrade_minor_version = kwargs.get('auto_upgrade_minor_version', True)
        self.release_train = kwargs.get('release_train', "Stable")
        self.version = kwargs.get('version', None)
        self.configuration_settings = kwargs.get('configuration_settings', None)
        self.configuration_protected_settings = kwargs.get('configuration_protected_settings', None)


class RepositoryRefDefinition(msrest.serialization.Model):
    """The source reference for the GitRepository object.

    :param branch: The git repository branch name to checkout.
    :type branch: str
    :param tag: The git repository tag name to checkout. This takes precedence over branch.
    :type tag: str
    :param semver: The semver range used to match against git repository tags. This takes
     precedence over tag.
    :type semver: str
    :param commit: The commit SHA to checkout. This value must be combined with the branch name to
     be valid. This takes precedence over semver.
    :type commit: str
    """

    _attribute_map = {
        'branch': {'key': 'branch', 'type': 'str'},
        'tag': {'key': 'tag', 'type': 'str'},
        'semver': {'key': 'semver', 'type': 'str'},
        'commit': {'key': 'commit', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(RepositoryRefDefinition, self).__init__(**kwargs)
        self.branch = kwargs.get('branch', None)
        self.tag = kwargs.get('tag', None)
        self.semver = kwargs.get('semver', None)
        self.commit = kwargs.get('commit', None)


class ResourceProviderOperation(msrest.serialization.Model):
    """Supported operation of this resource provider.

    Variables are only populated by the server, and will be ignored when sending a request.

    :param name: Operation name, in format of {provider}/{resource}/{operation}.
    :type name: str
    :param display: Display metadata associated with the operation.
    :type display:
     ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.ResourceProviderOperationDisplay
    :ivar is_data_action: The flag that indicates whether the operation applies to data plane.
    :vartype is_data_action: bool
    :ivar origin: Origin of the operation.
    :vartype origin: str
    """

    _validation = {
        'is_data_action': {'readonly': True},
        'origin': {'readonly': True},
    }

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'display': {'key': 'display', 'type': 'ResourceProviderOperationDisplay'},
        'is_data_action': {'key': 'isDataAction', 'type': 'bool'},
        'origin': {'key': 'origin', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(ResourceProviderOperation, self).__init__(**kwargs)
        self.name = kwargs.get('name', None)
        self.display = kwargs.get('display', None)
        self.is_data_action = None
        self.origin = None


class ResourceProviderOperationDisplay(msrest.serialization.Model):
    """Display metadata associated with the operation.

    :param provider: Resource provider: Microsoft KubernetesConfiguration.
    :type provider: str
    :param resource: Resource on which the operation is performed.
    :type resource: str
    :param operation: Type of operation: get, read, delete, etc.
    :type operation: str
    :param description: Description of this operation.
    :type description: str
    """

    _attribute_map = {
        'provider': {'key': 'provider', 'type': 'str'},
        'resource': {'key': 'resource', 'type': 'str'},
        'operation': {'key': 'operation', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(ResourceProviderOperationDisplay, self).__init__(**kwargs)
        self.provider = kwargs.get('provider', None)
        self.resource = kwargs.get('resource', None)
        self.operation = kwargs.get('operation', None)
        self.description = kwargs.get('description', None)


class ResourceProviderOperationList(msrest.serialization.Model):
    """Result of the request to list operations.

    Variables are only populated by the server, and will be ignored when sending a request.

    :param value: List of operations supported by this resource provider.
    :type value:
     list[~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.ResourceProviderOperation]
    :ivar next_link: URL to the next set of results, if any.
    :vartype next_link: str
    """

    _validation = {
        'next_link': {'readonly': True},
    }

    _attribute_map = {
        'value': {'key': 'value', 'type': '[ResourceProviderOperation]'},
        'next_link': {'key': 'nextLink', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(ResourceProviderOperationList, self).__init__(**kwargs)
        self.value = kwargs.get('value', None)
        self.next_link = None


class Scope(msrest.serialization.Model):
    """Scope of the extension. It can be either Cluster or Namespace; but not both.

    :param cluster: Specifies that the scope of the extension is Cluster.
    :type cluster: ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.ScopeCluster
    :param namespace: Specifies that the scope of the extension is Namespace.
    :type namespace: ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.ScopeNamespace
    """

    _attribute_map = {
        'cluster': {'key': 'cluster', 'type': 'ScopeCluster'},
        'namespace': {'key': 'namespace', 'type': 'ScopeNamespace'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(Scope, self).__init__(**kwargs)
        self.cluster = kwargs.get('cluster', None)
        self.namespace = kwargs.get('namespace', None)


class ScopeCluster(msrest.serialization.Model):
    """Specifies that the scope of the extension is Cluster.

    :param release_namespace: Namespace where the extension Release must be placed, for a Cluster
     scoped extension.  If this namespace does not exist, it will be created.
    :type release_namespace: str
    """

    _attribute_map = {
        'release_namespace': {'key': 'releaseNamespace', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(ScopeCluster, self).__init__(**kwargs)
        self.release_namespace = kwargs.get('release_namespace', None)


class ScopeNamespace(msrest.serialization.Model):
    """Specifies that the scope of the extension is Namespace.

    :param target_namespace: Namespace where the extension will be created for an Namespace scoped
     extension.  If this namespace does not exist, it will be created.
    :type target_namespace: str
    """

    _attribute_map = {
        'target_namespace': {'key': 'targetNamespace', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(ScopeNamespace, self).__init__(**kwargs)
        self.target_namespace = kwargs.get('target_namespace', None)


class SourceControlConfiguration(ProxyResource):
    """The SourceControl Configuration object returned in Get & Put response.

    Variables are only populated by the server, and will be ignored when sending a request.

    :ivar id: Fully qualified resource ID for the resource. Ex -
     /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}.
    :vartype id: str
    :ivar name: The name of the resource.
    :vartype name: str
    :ivar type: The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or
     "Microsoft.Storage/storageAccounts".
    :vartype type: str
    :ivar system_data: Top level metadata
     https://github.com/Azure/azure-resource-manager-rpc/blob/master/v1.0/common-api-contracts.md#system-metadata-for-all-azure-resources.
    :vartype system_data: ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.SystemData
    :param repository_url: Url of the SourceControl Repository.
    :type repository_url: str
    :param operator_namespace: The namespace to which this operator is installed to. Maximum of 253
     lower case alphanumeric characters, hyphen and period only.
    :type operator_namespace: str
    :param operator_instance_name: Instance name of the operator - identifying the specific
     configuration.
    :type operator_instance_name: str
    :param operator_type: Type of the operator. Possible values include: "Flux".
    :type operator_type: str or
     ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.OperatorType
    :param operator_params: Any Parameters for the Operator instance in string format.
    :type operator_params: str
    :param configuration_protected_settings: Name-value pairs of protected configuration settings
     for the configuration.
    :type configuration_protected_settings: dict[str, str]
    :param operator_scope: Scope at which the operator will be installed. Possible values include:
     "cluster", "namespace". Default value: "cluster".
    :type operator_scope: str or
     ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.OperatorScopeType
    :ivar repository_public_key: Public Key associated with this SourceControl configuration
     (either generated within the cluster or provided by the user).
    :vartype repository_public_key: str
    :param ssh_known_hosts_contents: Base64-encoded known_hosts contents containing public SSH keys
     required to access private Git instances.
    :type ssh_known_hosts_contents: str
    :param enable_helm_operator: Option to enable Helm Operator for this git configuration.
    :type enable_helm_operator: bool
    :param helm_operator_properties: Properties for Helm operator.
    :type helm_operator_properties:
     ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.HelmOperatorProperties
    :ivar provisioning_state: The provisioning state of the resource provider. Possible values
     include: "Accepted", "Deleting", "Running", "Succeeded", "Failed".
    :vartype provisioning_state: str or
     ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.ProvisioningStateType
    :ivar compliance_status: Compliance Status of the Configuration.
    :vartype compliance_status:
     ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.ComplianceStatus
    """

    _validation = {
        'id': {'readonly': True},
        'name': {'readonly': True},
        'type': {'readonly': True},
        'system_data': {'readonly': True},
        'repository_public_key': {'readonly': True},
        'provisioning_state': {'readonly': True},
        'compliance_status': {'readonly': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'system_data': {'key': 'systemData', 'type': 'SystemData'},
        'repository_url': {'key': 'properties.repositoryUrl', 'type': 'str'},
        'operator_namespace': {'key': 'properties.operatorNamespace', 'type': 'str'},
        'operator_instance_name': {'key': 'properties.operatorInstanceName', 'type': 'str'},
        'operator_type': {'key': 'properties.operatorType', 'type': 'str'},
        'operator_params': {'key': 'properties.operatorParams', 'type': 'str'},
        'configuration_protected_settings': {'key': 'properties.configurationProtectedSettings', 'type': '{str}'},
        'operator_scope': {'key': 'properties.operatorScope', 'type': 'str'},
        'repository_public_key': {'key': 'properties.repositoryPublicKey', 'type': 'str'},
        'ssh_known_hosts_contents': {'key': 'properties.sshKnownHostsContents', 'type': 'str'},
        'enable_helm_operator': {'key': 'properties.enableHelmOperator', 'type': 'bool'},
        'helm_operator_properties': {'key': 'properties.helmOperatorProperties', 'type': 'HelmOperatorProperties'},
        'provisioning_state': {'key': 'properties.provisioningState', 'type': 'str'},
        'compliance_status': {'key': 'properties.complianceStatus', 'type': 'ComplianceStatus'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(SourceControlConfiguration, self).__init__(**kwargs)
        self.system_data = None
        self.repository_url = kwargs.get('repository_url', None)
        self.operator_namespace = kwargs.get('operator_namespace', "default")
        self.operator_instance_name = kwargs.get('operator_instance_name', None)
        self.operator_type = kwargs.get('operator_type', None)
        self.operator_params = kwargs.get('operator_params', None)
        self.configuration_protected_settings = kwargs.get('configuration_protected_settings', None)
        self.operator_scope = kwargs.get('operator_scope', "cluster")
        self.repository_public_key = None
        self.ssh_known_hosts_contents = kwargs.get('ssh_known_hosts_contents', None)
        self.enable_helm_operator = kwargs.get('enable_helm_operator', None)
        self.helm_operator_properties = kwargs.get('helm_operator_properties', None)
        self.provisioning_state = None
        self.compliance_status = None


class SourceControlConfigurationList(msrest.serialization.Model):
    """Result of the request to list Source Control Configurations.  It contains a list of SourceControlConfiguration objects and a URL link to get the next set of results.

    Variables are only populated by the server, and will be ignored when sending a request.

    :ivar value: List of Source Control Configurations within a Kubernetes cluster.
    :vartype value:
     list[~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.SourceControlConfiguration]
    :ivar next_link: URL to get the next set of configuration objects, if any.
    :vartype next_link: str
    """

    _validation = {
        'value': {'readonly': True},
        'next_link': {'readonly': True},
    }

    _attribute_map = {
        'value': {'key': 'value', 'type': '[SourceControlConfiguration]'},
        'next_link': {'key': 'nextLink', 'type': 'str'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(SourceControlConfigurationList, self).__init__(**kwargs)
        self.value = None
        self.next_link = None


class SupportedScopes(msrest.serialization.Model):
    """Extension scopes.

    :param default_scope: Default extension scopes: cluster or namespace.
    :type default_scope: str
    :param cluster_scope_settings: Scope settings.
    :type cluster_scope_settings:
     ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.ClusterScopeSettings
    """

    _attribute_map = {
        'default_scope': {'key': 'defaultScope', 'type': 'str'},
        'cluster_scope_settings': {'key': 'clusterScopeSettings', 'type': 'ClusterScopeSettings'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(SupportedScopes, self).__init__(**kwargs)
        self.default_scope = kwargs.get('default_scope', None)
        self.cluster_scope_settings = kwargs.get('cluster_scope_settings', None)


class SystemData(msrest.serialization.Model):
    """Metadata pertaining to creation and last modification of the resource.

    :param created_by: The identity that created the resource.
    :type created_by: str
    :param created_by_type: The type of identity that created the resource. Possible values
     include: "User", "Application", "ManagedIdentity", "Key".
    :type created_by_type: str or
     ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.CreatedByType
    :param created_at: The timestamp of resource creation (UTC).
    :type created_at: ~datetime.datetime
    :param last_modified_by: The identity that last modified the resource.
    :type last_modified_by: str
    :param last_modified_by_type: The type of identity that last modified the resource. Possible
     values include: "User", "Application", "ManagedIdentity", "Key".
    :type last_modified_by_type: str or
     ~azure.mgmt.kubernetesconfiguration.v2021_11_01_preview.models.CreatedByType
    :param last_modified_at: The timestamp of resource last modification (UTC).
    :type last_modified_at: ~datetime.datetime
    """

    _attribute_map = {
        'created_by': {'key': 'createdBy', 'type': 'str'},
        'created_by_type': {'key': 'createdByType', 'type': 'str'},
        'created_at': {'key': 'createdAt', 'type': 'iso-8601'},
        'last_modified_by': {'key': 'lastModifiedBy', 'type': 'str'},
        'last_modified_by_type': {'key': 'lastModifiedByType', 'type': 'str'},
        'last_modified_at': {'key': 'lastModifiedAt', 'type': 'iso-8601'},
    }

    def __init__(
        self,
        **kwargs
    ):
        super(SystemData, self).__init__(**kwargs)
        self.created_by = kwargs.get('created_by', None)
        self.created_by_type = kwargs.get('created_by_type', None)
        self.created_at = kwargs.get('created_at', None)
        self.last_modified_by = kwargs.get('last_modified_by', None)
        self.last_modified_by_type = kwargs.get('last_modified_by_type', None)
        self.last_modified_at = kwargs.get('last_modified_at', None)
